Assorted spelling fixes

Francois Gouget fgouget at free.fr
Wed Aug 17 02:20:07 CDT 2005


Changelog:

  * dlls/kernel/tests/process.c
    dlls/msxml3/domdoc.c
    dlls/secur32/tests/main.c
    dlls/wined3d/drawprim.c

    Francois Gouget <fgouget at free.fr>
    Assorted spelling fixes.

-- 
Francois Gouget         fgouget at free.fr        http://fgouget.free.fr/
      You can have my guns when you pry them from my kids cold, dead hands.
-------------- next part --------------
Index: dlls/kernel/tests/process.c
===================================================================
RCS file: /var/cvs/wine/dlls/kernel/tests/process.c,v
retrieving revision 1.21
diff -u -p -r1.21 process.c
--- dlls/kernel/tests/process.c	27 Jun 2005 09:54:09 -0000	1.21
+++ dlls/kernel/tests/process.c	12 Aug 2005 10:27:04 -0000
@@ -415,7 +415,7 @@ static int strCmp(const char* s1, const 
         ok(strCmp(result, expect, 0) == 0, "%s:%s expected '%s', got '%s'\n", sect, key, expect, result); \
     } while (0)
 
-/* using !expect insures that the test will fail if the sect/key isn't present
+/* using !expect ensures that the test will fail if the sect/key isn't present
  * in result file
  */
 #define okChildInt(sect, key, expect) \
Index: dlls/msxml3/domdoc.c
===================================================================
RCS file: /var/cvs/wine/dlls/msxml3/domdoc.c,v
retrieving revision 1.7
diff -u -p -r1.7 domdoc.c
--- dlls/msxml3/domdoc.c	12 Aug 2005 10:35:17 -0000	1.7
+++ dlls/msxml3/domdoc.c	16 Aug 2005 12:08:54 -0000
@@ -655,7 +655,7 @@ static xmlDocPtr doparse( char *ptr, int
 {
 #ifdef HAVE_XMLREADMEMORY
     /*
-     * use xmlReadMemory if possible so we can supress
+     * use xmlReadMemory if possible so we can suppress
      * writing errors to stderr
      */
     return xmlReadMemory( ptr, len, NULL, NULL,
Index: dlls/wined3d/drawprim.c
===================================================================
RCS file: /var/cvs/wine/dlls/wined3d/drawprim.c,v
retrieving revision 1.27
diff -u -p -r1.27 drawprim.c
--- dlls/wined3d/drawprim.c	12 Aug 2005 18:22:06 -0000	1.27
+++ dlls/wined3d/drawprim.c	16 Aug 2005 22:42:34 -0000
@@ -1585,7 +1585,7 @@ void inline drawPrimitiveUploadTextures(
 * if there is a texture bound to that unit then..
 * disable all textures types on that unit
 * enable and bind the texture that is bound to that unit.
-* otherwise dissable all texture types on that unit.
+* otherwise disable all texture types on that unit.
 **/
     /* upload the textures */
     for (i = 0; i< GL_LIMITS(textures); ++i) {


More information about the wine-patches mailing list
Index: dlls/secur32/tests/main.c
===================================================================
RCS file: /var/cvs/wine/dlls/secur32/tests/main.c,v
retrieving revision 1.3
diff -u -p -r1.3 main.c
--- dlls/secur32/tests/main.c	15 Aug 2005 20:52:18 -0000	1.3
+++ dlls/secur32/tests/main.c	16 Aug 2005 04:45:44 -0000
@@ -307,15 +307,14 @@ static void testQuerySecurityPackageInfo
         "Return value of FreeContextBuffer() shouldn't be %s\n",
         getSecStatusError(sec_status) );
 
     /* Test with non-existing package, test should fail */
    
     lstrcpy(sec_pkg_name, "Winetest");
 
     sec_status = QuerySecurityPackageInfo( sec_pkg_name, &pkg_info);
 
     ok( sec_status != SEC_E_OK,
-        "Return value of QuerySecurityPackageInfo() should not be %s for \
-a non-existant package\n", getSecStatusError(SEC_E_OK));
+        "Return value of QuerySecurityPackageInfo() should not be %s for a nonexistent package\n", getSecStatusError(SEC_E_OK));
 
     sec_status = FreeContextBuffer(&pkg_info);
     
@@ -307,15 +307,14 @@ static void testQuerySecurityPackageInfo
         getSecStatusError(sec_status) );
 
-    /* Test with non-existing package, test should fail */
+    /* Test with a nonexistent package, test should fail */
    
     lstrcpy(sec_pkg_name, "Winetest");